pub struct Type {
pub namespace: Vec<String>,
pub name: String,
pub bare: bool,
pub generic_ref: bool,
pub generic_arg: Option<Box<Type>>,
}Expand description
The type of a definition or a parameter.
Fields
namespace: Vec<String>The namespace components of the type.
name: StringThe name of the type.
bare: boolWhether this type is bare or boxed.
generic_ref: boolWhether the type name refers to a generic definition.
generic_arg: Option<Box<Type>>If the type has a generic argument, which is its type.